authRequestID property
The id of the authentication request. This is also used to generate auth headers for calls to the identification urls.
Implementation
final String authRequestID;
The id of the authentication request. This is also used to generate auth headers for calls to the identification urls.
final String authRequestID;